pub enum HyperliquidExchangeOrderStatus {
Resting {
resting: HyperliquidExchangeRestingInfo,
},
Filled {
filled: HyperliquidExchangeFilledInfo,
},
Error {
error: String,
},
Tag(HyperliquidExchangeOrderStatusTag),
}Expand description
Status of an individual order submission via exchange endpoint.
Variants
Resting
Order is resting on the order book.
Fields

resting: HyperliquidExchangeRestingInfoResting order information.
Filled
Order was filled immediately.
Fields

filled: HyperliquidExchangeFilledInfoFill information.
Error
Order submission failed.
Tag(HyperliquidExchangeOrderStatusTag)
Bare status string for a trigger child of a normalTpsl group (SL/TP),
which Hyperliquid serializes as a JSON string rather than an object
(for example "waitingForFill" or "waitingForTrigger").